@@ -77,6 +77,7 @@ typedef enum
 GType         g_irepository_get_type      (void) G_GNUC_CONST;
 GIRepository *g_irepository_get_default   (void);
 void          g_irepository_prepend_search_path (const char *directory);
+GSList *      g_irepository_get_search_path     (void);
 const char *  g_irepository_load_typelib  (GIRepository *repository,
 					   GTypelib     *typelib,
 					   GIRepositoryLoadFlags flags,
@@ -109,6 +110,10 @@ const gchar * g_irepository_get_shared_library (GIRepository *repository,
 const gchar * g_irepository_get_version (GIRepository *repository,
 					 const gchar  *namespace);
 
+GOptionGroup * g_irepository_get_option_group (void);
+
+gboolean       g_irepository_dump  (const char *arg, GError **error);
+
 /* Typelib */
 
 GTypelib *   g_typelib_new_from_memory       (guchar       *memory,
@@ -351,6 +356,12 @@ gint                   g_field_info_get_size       (GIFieldInfo *info);
 gint                   g_field_info_get_offset     (GIFieldInfo *info);
 GITypeInfo *           g_field_info_get_type       (GIFieldInfo *info);
 
+gboolean g_field_info_get_field (GIFieldInfo     *field_info,
+				 gpointer         mem,
+				 GArgument       *value);
+gboolean g_field_info_set_field (GIFieldInfo     *field_info,
+				 gpointer         mem,
+				 const GArgument *value);
 
 /* GIUnionInfo */
 gint                   g_union_info_get_n_fields  (GIUnionInfo *info);
@@ -366,6 +377,8 @@ GIConstantInfo *       g_union_info_get_discriminator      (GIUnionInfo *info,
 					                    gint         n);
 GIFunctionInfo *       g_union_info_find_method    (GIUnionInfo *info,
                                                     const gchar *name);
+gsize                  g_union_info_get_size       (GIUnionInfo *info);
+gsize                  g_union_info_get_alignment  (GIUnionInfo *info);
 
 
 /* GIStructInfo */
@@ -377,6 +390,8 @@ GIFunctionInfo *       g_struct_info_get_method    (GIStructInfo *info,
 						    gint         n);
 GIFunctionInfo *       g_struct_info_find_method   (GIStructInfo *info,
 						    const gchar *name);
+gsize                  g_struct_info_get_size      (GIStructInfo *info);
+gsize                  g_struct_info_get_alignment (GIStructInfo *info);
 
 /* GIRegisteredTypeInfo */
 
@@ -389,6 +404,7 @@ GType                  g_registered_type_info_get_g_type    (GIRegisteredTypeInf
 gint                   g_enum_info_get_n_values             (GIEnumInfo      *info);
 GIValueInfo  *         g_enum_info_get_value                (GIEnumInfo      *info,
 							     gint            n);
+GITypeTag              g_enum_info_get_storage_type         (GIEnumInfo      *info);
 
 /* GIObjectInfo */
 
