@@ -2,20 +2,20 @@
 # GObject-Introspection - a framework for introspecting GObject libraries
 # Copyright (C) 2008  Johan Dahlin
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2 of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the
+# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+# Boston, MA 02111-1307, USA.
 #
 
 """AST nodes
@@ -86,7 +86,7 @@ type_names = {}
 for name in GIR_TYPES:
     type_names[name] = name
 
-# C
+# C builtin
 type_names['char'] = TYPE_INT8
 type_names['signed char'] = TYPE_INT8
 type_names['unsigned char'] = TYPE_UINT8
@@ -106,11 +106,13 @@ type_names['double'] = TYPE_DOUBLE
 type_names['char*'] = TYPE_STRING
 type_names['void*'] = TYPE_ANY
 type_names['void'] = TYPE_NONE
+
+# C unix types
+type_names['off_t'] = TYPE_SIZET
+type_names['pid_t'] = TYPE_INT
 type_names['size_t'] = TYPE_SIZET
 type_names['ssize_t'] = TYPE_SSIZET
-type_names['off_t'] = TYPE_SIZET
-# FIXME - can we make libraries use GPid?
-type_names['pid_t'] = TYPE_INT
+type_names['socklen_t'] = TYPE_INT32
 
 # Obj-C
 type_names['id'] = TYPE_ANY
@@ -129,7 +131,7 @@ type_names['constpointer'] = TYPE_ANY
 # If you add/change these, be sure to update glibast.py too
 default_array_types = {}
 default_array_types['uint8*'] = TYPE_UINT8
-default_array_types['char**'] = TYPE_STRING
+default_array_types['utf8*'] = TYPE_STRING
 
 # These types, when seen by reference, are interpreted as out parameters
 default_out_types = (TYPE_INT, TYPE_UINT, TYPE_LONG, TYPE_ULONG,
@@ -324,11 +326,12 @@ class Member(Node):
 
 class Struct(Node):
 
-    def __init__(self, name, symbol):
+    def __init__(self, name, symbol, disguised=False):
         Node.__init__(self, name)
         self.fields = []
         self.constructors = []
         self.symbol = symbol
+        self.disguised = disguised
 
 
 class Field(Node):
@@ -365,6 +368,7 @@ class Class(Node):
         self.parent = parent
         self.is_abstract = is_abstract
         self.methods = []
+        self.static_methods = []
         self.interfaces = []
         self.constructors = []
         self.properties = []
@@ -384,6 +388,7 @@ class Interface(Node):
         self.methods = []
         self.properties = []
         self.fields = []
+        self.prerequisites = []
 
     def __repr__(self):
         return '%s(%r, %r)' % (
@@ -430,6 +435,7 @@ class Callback(Node):
         self.retval = retval
         self.parameters = parameters
         self.ctype = ctype
+        self.throws = False
 
     def __repr__(self):
         return 'Callback(%r, %r, %r)' % (
