@@ -20,6 +20,9 @@ struct _UtilityObjectClass
   GObjectClass parent_class;
 };
 
+/* This one is similar to Pango.Glyph */
+typedef guint32 UtilityGlyph;
+
 GType                 utility_object_get_type          (void) G_GNUC_CONST;
 
 typedef enum
@@ -39,6 +42,16 @@ typedef enum
 typedef struct
 {
   int field;
+  guint bitfield1 : 3;
+  guint bitfield2 : 2;
+  guint8 data[16];
 } UtilityStruct;
 
+typedef union
+{
+  char *pointer;
+  glong integer;
+  double real;
+} UtilityUnion;
+  
 #endif /* __UTILITY_H__ */
